{% load i18n %}
{% load admin_urls %}

{% if has_import_permission %}
<a href='{% url opts|admin_urlname:"import" %}' class="import_link btn btn-outline-secondary">
    <i class="fas fa-file-import"></i> {% trans "Import" %}
</a>
{% endif %}
